chainalysis.orm.orm - Data Solutions Python SDK 0.7.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for chainalysis.orm.orm

    from chainalysis.orm._transactional_select import TransactionalSelect
    from chainalysis.orm._analytical_select import AnalyticalSelect

    class Orm:
        # pragma: no cover

        def TransactionalSelect(self, chain_table_name: str) -> TransactionalSelect:
            """
            Method to create a TransactionalTable object.

            :param chain_table_name: The name of the chain table.
            :type chain_table_name: str
            :return: TransactionalTable object.
            :rtype: TransactionalTable
            """
            return TransactionalSelect(self.api_key, chain_table_name)

        # pragma: no cover

        def AnalyticalSelect(self, chain_table_name: str) -> AnalyticalSelect:
            """
            Method to create an AnalyticalTable object.

            :param chain_table_name: The name of the chain table.
            :type chain_table_name: str
            :return: AnalyticalTable object.
            :rtype: AnalyticalTable
            """
            return AnalyticalSelect(self.api_key, chain_table_name)